==> common_api-3.5.0.0-sources.jar: main/com/cloud/sdk/commonutil/util/HSCoreUtil.java <==
package com.cloud.sdk.commonutil.util;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.pm.PackageInfo;
import android.os.Environment;
import androidx.annotation.NonNull;

import com.cloud.sdk.commonutil.deviceinfo.HSDeviceInfo;

import java.io.File;
import java.lang.reflect.Field;

public class HSCoreUtil {
    @SuppressLint({"StaticFieldLeak"})
    private static Context context;
    private static boolean isDebug;
    private static boolean isInit = false;

    private HSCoreUtil() {
        throw new UnsupportedOperationException("u can't instantiate me...");
    }

    public static void init(@NonNull Context context) {
        if (!isInit()) {
            isInit = true;
            HSCoreUtil.context = context.getApplicationContext();
            HSDeviceInfo.getGAId();
            HSSharedPreferencesUtil.bindApplication(getContext());
        }
    }

    public static void setContext(Context context) {
        HSCoreUtil.context = context.getApplicationContext();
    }

    public static boolean isInit() {
        return isInit && context != null;
    }

    public static Context getContext() {
        if (context != null) {
            return context;
        } else {
            throw new NullPointerException("u should init first");
        }
    }

    public static boolean isDebug() {
        return isDebug;
    }

    public static void setDebug(boolean isDebug) {
        HSCoreUtil.isDebug = isDebug;
    }

    public static String getPkgName() {
        return HSCoreUtil.getContext().getPackageName();
    }

    public static File getExternalCacheDir(Context context) {
        File cacheDir = null;

        boolean isUserRequired;
        try {
            @SuppressLint("SoonBlockedPrivateApi") Field privateBoolField = Environment.class.getDeclaredField("sUserRequired");
            privateBoolField.setAccessible(true);
            Environment user = new Environment();
            isUserRequired = privateBoolField.getBoolean(user);
        } catch (Exception var6) {
            isUserRequired = true;
        }

        try {
            if (!isUserRequired) {
                cacheDir = context.getExternalCacheDir();
            }
        } catch (Exception var5) {
            var5.printStackTrace();
        }

        return cacheDir;
    }

    public static String getVersionName() {
        String versionName = "";
        Context context = HSCoreUtil.getContext();

        try {
            PackageInfo pi = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
            if (pi != null) {
                versionName = pi.versionName;
            }
        } catch (Exception var3) {
            var3.printStackTrace();
        }

        return versionName;
    }

    public static int getVersionCode() {
        int versionCode = -1;
        Context context = HSCoreUtil.getContext();

        try {
            PackageInfo pi = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
            if (pi != null) {
                versionCode = pi.versionCode;
            }
        } catch (Exception var3) {
            var3.printStackTrace();
        }

        return versionCode;
    }
}

==> common_api-3.5.0.3-sources.jar: main/com/cloud/sdk/commonutil/util/HSCoreUtil.java <==
package com.cloud.sdk.commonutil.util;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.pm.PackageInfo;
import android.os.Environment;

import androidx.annotation.NonNull;

import com.cloud.sdk.commonutil.deviceinfo.HSDeviceInfo;

import java.io.File;
import java.lang.reflect.Field;

public class HSCoreUtil {
    @SuppressLint({"StaticFieldLeak"})
    private static volatile Context context;
    private static volatile boolean isDebug;
    private static volatile boolean isInit = false;

    private HSCoreUtil() {
        throw new UnsupportedOperationException("u can't instantiate me...");
    }

    public synchronized static void init(@NonNull Context context) {
        if (!isInit()) {
            isInit = true;
            HSCoreUtil.context = context.getApplicationContext();
            HSDeviceInfo.getGAId();
            HSSharedPreferencesUtil.bindApplication(getContext());
        }
    }

    public static void setContext(Context context) {
        try {
            HSCoreUtil.context = context.getApplicationContext();
        }catch (Throwable t){
            CommonLogUtil.Log().e("context is null, please check it");
        }
    }

    public static boolean isInit() {
        return isInit && context != null;
    }

    public static Context getContext() {
        if (context == null) {
            CommonLogUtil.Log().e("u should init first");
        }
        return context;
    }

    public static boolean isDebug() {
        return isDebug;
    }

    public static void setDebug(boolean isDebug) {
        HSCoreUtil.isDebug = isDebug;
    }

    public static String getPkgName() {
        return HSCoreUtil.getContext().getPackageName();
    }

    public static File getExternalCacheDir(Context context) {
        File cacheDir = null;

        boolean isUserRequired;
        try {
            @SuppressLint("SoonBlockedPrivateApi") Field privateBoolField = Environment.class.getDeclaredField("sUserRequired");
            privateBoolField.setAccessible(true);
            Environment user = new Environment();
            isUserRequired = privateBoolField.getBoolean(user);
        } catch (Exception var6) {
            isUserRequired = true;
        }

        try {
            if (!isUserRequired) {
                cacheDir = context.getExternalCacheDir();
            }
        } catch (Exception var5) {
            var5.printStackTrace();
        }

        return cacheDir;
    }

    public static String getVersionName() {
        String versionName = "";
        Context context = HSCoreUtil.getContext();
        if (context == null) {
            return versionName;
        }
        try {
            PackageInfo pi = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
            if (pi != null) {
                versionName = pi.versionName;
            }
        } catch (Exception var3) {
            var3.printStackTrace();
        }

        return versionName;
    }

    public static int getVersionCode() {
        int versionCode = -1;
        Context context = HSCoreUtil.getContext();
        if (context == null) {
            return versionCode;
        }
        try {
            PackageInfo pi = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
            if (pi != null) {
                versionCode = pi.versionCode;
            }
        } catch (Exception var3) {
            var3.printStackTrace();
        }

        return versionCode;
    }
}
